@@ -35,6 +35,8 @@ from deepdriver.sdk.experiment import *
 from deepdriver.sdk.login import *
 from deepdriver.sdk.setting import *
 from deepdriver.sdk.run import *
+from deepdriver.sdk.watch import watch
+
 from deepdriver.sdk.visualization import visualize
 from deepdriver.sdk.chart.histogram import histogram
 from deepdriver.sdk.chart.line import line
@@ -47,8 +49,12 @@ from deepdriver.sdk.data_types.image import Image
 from deepdriver.sdk.data_types.table import Table
 
 
+#layzyload
 from deepdriver.sdk.lib.lazyloader import LazyLoader
-keras = LazyLoader('deepdriver.intergration.keras', globals(), 'deepdriver.intergration.keras.keras')  #layzyload
+keras = LazyLoader('deepdriver.intergration.keras', globals(), 'deepdriver.intergration.keras.keras')
+torch = LazyLoader('deepdriver.intergration.torch', globals(), 'deepdriver.intergration.torch.torch')
+
+
 
 config = Config()
 
